@@ -40,9 +40,9 @@
 #endif
 
 #define GOT_DELTA_CACHE_MIN_BUCKETS	64
-#define GOT_DELTA_CACHE_MAX_BUCKETS	16384
+#define GOT_DELTA_CACHE_MAX_BUCKETS	2048
 #define GOT_DELTA_CACHE_MAX_CHAIN	2
-#define GOT_DELTA_CACHE_MAX_DELTA_SIZE	2048
+#define GOT_DELTA_CACHE_MAX_DELTA_SIZE	1024
 
 struct got_cached_delta {
 	off_t offset;
@@ -126,7 +126,7 @@ delta_cache_hash(struct got_delta_cache *cache, off_t delta_offset)
 	return SipHash24(&cache->key, &delta_offset, sizeof(delta_offset));
 }
 
-#ifndef GOT_NO_OBJ_CACHE
+#ifndef GOT_NO_DELTA_CACHE
 static const struct got_error *
 delta_cache_resize(struct got_delta_cache *cache, unsigned int nbuckets)
 {
@@ -158,8 +158,10 @@ delta_cache_resize(struct got_delta_cache *cache, unsigned int nbuckets)
 				new_delta = &head->entries[head->nchain];
 				memcpy(new_delta, delta, sizeof(*new_delta));
 				head->nchain++;
-			} else
+			} else {
 				free(delta->data);
+				cache->totelem--;
+			}
 		}
 	}
 
@@ -191,7 +193,7 @@ const struct got_error *
 got_delta_cache_add(struct got_delta_cache *cache,
     off_t delta_data_offset, uint8_t *delta_data, size_t delta_len)
 {
-#ifdef GOT_NO_OBJ_CACHE
+#ifdef GOT_NO_DELTA_CACHE
 	return got_error(GOT_ERR_NO_SPACE);
 #else
 	const struct got_error *err = NULL;
@@ -217,6 +219,8 @@ got_delta_cache_add(struct got_delta_cache *cache,
 		free(delta->data);
 		memset(delta, 0, sizeof(*delta));
 		head->nchain--;
+		cache->totelem--;
+		cache->cache_evict++;
 	}
 
 	delta = &head->entries[head->nchain];
