@@ -86,6 +86,16 @@ struct patch_args {
 	struct got_patch_hunk_head *head;
 };
 
+static mode_t
+apply_umask(mode_t mode)
+{
+	mode_t um;
+
+	um = umask(000);
+	umask(um);
+	return mode & ~um;
+}
+
 static const struct got_error *
 send_patch(struct imsgbuf *ibuf, int fd)
 {
@@ -704,7 +714,8 @@ open_blob(char **path, FILE **fp, const char *blobid,
 	if (err)
 		goto done;
 
-	err = got_opentemp_named(path, fp, GOT_TMPDIR_STR "/got-patch-blob");
+	err = got_opentemp_named(path, fp, GOT_TMPDIR_STR "/got-patch-blob",
+	    "");
 	if (err)
 		goto done;
 
@@ -836,7 +847,7 @@ apply_patch(int *overlapcnt, struct got_worktree *worktree,
 	} else if (p->xbit)
 		mode |= (S_IXUSR | S_IXGRP | S_IXOTH);
 
-	err = got_opentemp_named(&tmppath, &tmpfile, template);
+	err = got_opentemp_named(&tmppath, &tmpfile, template, "");
 	if (err)
 		goto done;
 	outfd = fileno(tmpfile);
@@ -893,7 +904,7 @@ apply_patch(int *overlapcnt, struct got_worktree *worktree,
 			tmpfile = t;
 		}
 
-		err = got_opentemp_named(&mergepath, &mergefile, template);
+		err = got_opentemp_named(&mergepath, &mergefile, template, "");
 		if (err)
 			goto done;
 		outfd = fileno(mergefile);
@@ -914,7 +925,7 @@ apply_patch(int *overlapcnt, struct got_worktree *worktree,
 		goto done;
 	}
 
-	if (fchmod(outfd, mode) == -1) {
+	if (fchmod(outfd, apply_umask(mode)) == -1) {
 		err = got_error_from_errno2("chmod", tmppath);
 		goto done;
 	}
