@@ -59,6 +59,7 @@
 #include "got_lib_privsep.h"
 #include "got_lib_object_cache.h"
 #include "got_lib_repository.h"
+#include "got_lib_ratelimit.h"
 #include "got_lib_pack_create.h"
 #include "got_lib_dial.h"
 
@@ -340,7 +341,8 @@ got_send_pack(const char *remote_name, struct got_pathlist_head *branch_names,
 	off_t bytes_sent = 0, bytes_sent_cur = 0;
 	struct pack_progress_arg ppa;
 	uint8_t packsha1[SHA1_DIGEST_LENGTH];
-	FILE *packfile = NULL;
+	int packfd = -1;
+	FILE *delta_cache = NULL;
 
 	TAILQ_INIT(&refs);
 	TAILQ_INIT(&have_refs);
@@ -431,8 +433,14 @@ got_send_pack(const char *remote_name, struct got_pathlist_head *branch_names,
 		}
 	}
 
-	packfile = got_opentemp();
-	if (packfile == NULL) {
+	packfd = got_opentempfd();
+	if (packfd == -1) {
+		err = got_error_from_errno("got_opentempfd");
+		goto done;
+	}
+
+	delta_cache = got_opentemp();
+	if (delta_cache == NULL) {
 		err = got_error_from_errno("got_opentemp");
 		goto done;
 	}
@@ -628,21 +636,18 @@ got_send_pack(const char *remote_name, struct got_pathlist_head *branch_names,
 	}
 
 	if (refs_to_send > 0) {
+		struct got_ratelimit rl;
+		got_ratelimit_init(&rl, 0, 500);
 		memset(&ppa, 0, sizeof(ppa));
 		ppa.progress_cb = progress_cb;
 		ppa.progress_arg = progress_arg;
-		err = got_pack_create(packsha1, packfile, their_ids, ntheirs,
-		    our_ids, nours, repo, 0, 1, pack_progress, &ppa,
-		    cancel_cb, cancel_arg);
+		err = got_pack_create(packsha1, packfd, delta_cache,
+		    their_ids, ntheirs, our_ids, nours, repo, 0, 1,
+		    pack_progress, &ppa, &rl, cancel_cb, cancel_arg);
 		if (err)
 			goto done;
 
-		if (fflush(packfile) == -1) {
-			err = got_error_from_errno("fflush");
-			goto done;
-		}
-
-		npackfd = dup(fileno(packfile));
+		npackfd = dup(packfd);
 		if (npackfd == -1) {
 			err = got_error_from_errno("dup");
 			goto done;
@@ -706,7 +711,9 @@ done:
 		if (waitpid(sendpid, &sendstatus, 0) == -1 && err == NULL)
 			err = got_error_from_errno("waitpid");
 	}
-	if (packfile && fclose(packfile) == EOF && err == NULL)
+	if (packfd != -1 && close(packfd) == -1 && err == NULL)
+		err = got_error_from_errno("close");
+	if (delta_cache && fclose(delta_cache) == EOF && err == NULL)
 		err = got_error_from_errno("fclose");
 	if (nsendfd != -1 && close(nsendfd) == -1 && err == NULL)
 		err = got_error_from_errno("close");
