@@ -189,7 +189,7 @@ send_ref(int outfd, uint8_t *id, const char *refname, int send_capabilities,
 	char buf[GOT_PKT_MAX];
 	size_t len, capalen = 0;
 
-	if (got_sha1_digest_to_str(id, hex, sizeof(hex)) == NULL) 
+	if (got_sha1_digest_to_str(id, hex, sizeof(hex)) == NULL)
 		return got_error(GOT_ERR_BAD_OBJ_ID);
 
 	len = snprintf(buf, sizeof(buf), "%s %s", hex, refname);
@@ -220,7 +220,7 @@ send_ref(int outfd, uint8_t *id, const char *refname, int send_capabilities,
 }
 
 static const struct got_error *
-send_zero_refs(int outfd, int chattygot)
+send_zero_refs(int outfd, int client_is_reading, int chattygot)
 {
 	const struct got_error *err = NULL;
 	char buf[GOT_PKT_MAX];
@@ -230,19 +230,27 @@ send_zero_refs(int outfd, int chattygot)
 
 	memset(&zero, 0, sizeof(zero));
 
-	if (got_sha1_digest_to_str(zero, hex, sizeof(hex)) == NULL) 
+	if (got_sha1_digest_to_str(zero, hex, sizeof(hex)) == NULL)
 		return got_error(GOT_ERR_BAD_OBJ_ID);
 
 	len = snprintf(buf, sizeof(buf), "%s capabilities^{}", hex);
 	if (len >= sizeof(buf))
 		return got_error(GOT_ERR_NO_SPACE);
 
-	err = got_gitproto_append_capabilities(&capalen, buf, len,
-	    sizeof(buf), read_capabilities, nitems(read_capabilities));
-	if (err)
-		return err;
+	if (client_is_reading) {
+		err = got_gitproto_append_capabilities(&capalen, buf, len,
+		    sizeof(buf), read_capabilities, nitems(read_capabilities));
+		if (err)
+			return err;
+	} else {
+		err = got_gitproto_append_capabilities(&capalen, buf, len,
+		    sizeof(buf), write_capabilities,
+		    nitems(write_capabilities));
+		if (err)
+			return err;
+	}
 
-	return got_pkt_writepkt(outfd, buf, len, chattygot);
+	return got_pkt_writepkt(outfd, buf, len + capalen, chattygot);
 }
 
 static void
@@ -315,7 +323,8 @@ announce_refs(int outfd, struct imsgbuf *ibuf, int client_is_reading,
 			nrefs = ireflist.nrefs;
 			have_nrefs = 1;
 			if (nrefs == 0)
-				err = send_zero_refs(outfd, chattygot);
+				err = send_zero_refs(outfd, client_is_reading,
+				    chattygot);
 			break;
 		case GOTD_IMSG_REF:
 			if (!have_nrefs || nrefs == 0) {
@@ -673,7 +682,7 @@ send_ack(int outfd, uint8_t *id, int chattygot)
 	char buf[GOT_PKT_MAX];
 	int len;
 
-	if (got_sha1_digest_to_str(id, hex, sizeof(hex)) == NULL) 
+	if (got_sha1_digest_to_str(id, hex, sizeof(hex)) == NULL)
 		return got_error(GOT_ERR_BAD_OBJ_ID);
 
 	len = snprintf(buf, sizeof(buf), "ACK %s\n", hex);
@@ -846,8 +855,8 @@ relay_progress_reports(struct imsgbuf *ibuf, int outfd, int chattygot)
 			    "%d commits colored, "
 			    "%d objects found, "
 			    "deltify %d%%%s",
-			    iprog.ncolored, 
-			    iprog.nfound, 
+			    iprog.ncolored,
+			    iprog.nfound,
 			    p_deltify, eol);
 			if (n >= sizeof(buf) - 1)
 				break;
